"use strict";

import React from 'react';
import { Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
function SyntaxHighlighter({
  text,
  lang,
  theme = 'github-dark',
  fontSize
}) {
  const {
    tokens,
    error,
    isLoading
  } = useSyntaxHighlighter({
    text,
    lang,
    theme
  });
  if (error) {
    return /*#__PURE__*/_jsxs(Text, {
      style: {
        color: '#ff6b6b',
        fontFamily: 'monospace',
        fontSize
      },
      children: ["Error:", error]
    });
  }
  if (isLoading) {
    return /*#__PURE__*/_jsx(Text, {
      style: {
        color: '#f8f8f2',
        fontFamily: 'monospace',
        fontSize
      },
      children: "Loading..."
    });
  }
  return /*#__PURE__*/_jsx(View, {
    children: tokens.map((line, lineIndex) => /*#__PURE__*/_jsxs(View, {
      style: {
        flexDirection: 'row',
        flexWrap: 'wrap'
      },
      children: [line.map((token, tokenIndex) => /*#__PURE__*/_jsx(Text, {
        style: {
          color: token.color || '#FFFFFF',
          fontFamily: 'monospace',
          fontSize,
          fontStyle: token.fontStyle
        },
        children: token.content.replace(/ /g, '\u00A0')
      }, `${lineIndex}-${tokenIndex}`)), /*#__PURE__*/_jsx(Text, {
        style: {
          color: '#FFFFFF',
          fontFamily: 'monospace',
          fontSize
        },
        children: '\n'
      })]
    }, `line-${lineIndex}`))
  });
}
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map