import type { BundledLanguage } from 'shiki/langs'
import type { SupportedLanguage } from '../../syntax/highlighter'
import { removeExtraIndentation } from '../../utils'

export interface ParsedCodeFence {
  code: string
  language: BundledLanguage
  valid: boolean
  outsideText: string[]
}

const CODE_BLOCK_REGEX = /```([a-z0-9]+)?\n([\s\S]*?)\n```/gi

export function parseCodeFence(text: string, defaultLang?: SupportedLanguage): ParsedCodeFence {
  const matches = [...text.matchAll(CODE_BLOCK_REGEX)]
  if (matches.length === 0) {
    return {
      code: text,
    } as ParsedCodeFence
  }

  const code = matches[0]?.[2] || ''
  const language = (matches[0]?.[1] as unknown as SupportedLanguage) || defaultLang
  const outsideText = text.split(CODE_BLOCK_REGEX).filter(Boolean)

  return {
    code: removeExtraIndentation(code),
    language,
    valid: true,
    outsideText,
  }
}
